@@ -286,9 +286,19 @@ ALL_ROUTES = [
     ('subnet', 'SoftLayer.CLI.subnet'),
     ('subnet:cancel', 'SoftLayer.CLI.subnet.cancel:cli'),
     ('subnet:create', 'SoftLayer.CLI.subnet.create:cli'),
+    ('subnet:edit', 'SoftLayer.CLI.subnet.edit:cli'),
     ('subnet:detail', 'SoftLayer.CLI.subnet.detail:cli'),
     ('subnet:list', 'SoftLayer.CLI.subnet.list:cli'),
     ('subnet:lookup', 'SoftLayer.CLI.subnet.lookup:cli'),
+    ('subnet:edit-ip', 'SoftLayer.CLI.subnet.edit_ip:cli'),
+
+    ('tags', 'SoftLayer.CLI.tags'),
+    ('tags:cleanup', 'SoftLayer.CLI.tags.cleanup:cli'),
+    ('tags:list', 'SoftLayer.CLI.tags.list:cli'),
+    ('tags:set', 'SoftLayer.CLI.tags.set:cli'),
+    ('tags:details', 'SoftLayer.CLI.tags.details:cli'),
+    ('tags:delete', 'SoftLayer.CLI.tags.delete:cli'),
+    ('tags:taggable', 'SoftLayer.CLI.tags.taggable:cli'),
 
     ('ticket', 'SoftLayer.CLI.ticket'),
     ('ticket:create', 'SoftLayer.CLI.ticket.create:cli'),
@@ -314,6 +324,7 @@ ALL_ROUTES = [
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
+    ('vlan:edit', 'SoftLayer.CLI.vlan.edit:cli'),
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
 
     ('summary', 'SoftLayer.CLI.summary:cli'),
